pub struct HeapProfiler {
config: HeapProfilingConfig,
threshold_auto_dump_heap_profile: usize,
jemalloc_dump_mib: dump_mib,
opt_prof: bool,
}Expand description
HeapProfiler automatically triggers heap profiling when memory usage is higher than the threshold.
To use it, both jemalloc’s opt.prof and RisingWave’s config heap_profiling.enable_auto must be set to true.
Fields
config: HeapProfilingConfigthreshold_auto_dump_heap_profile: usizejemalloc_dump_mib: dump_mibopt_prof: boolIf jemalloc profiling is enabled
Implementations
Sourceimpl HeapProfiler
impl HeapProfiler
Sourcepub fn new(total_memory: usize, config: HeapProfilingConfig) -> Self
pub fn new(total_memory: usize, config: HeapProfilingConfig) -> Self
Arguments
total_memory must be the total available memory for the process.
It will be compared with the process resident memory.
fn auto_dump_heap_prof(&self)